mailr5320 - /1.3/specific_fns/consistency_tests.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by sebastien . morin . 1 on April 04, 2008 - 17:21:
Author: semor
Date: Fri Apr  4 17:21:16 2008
New Revision: 5320

URL: http://svn.gna.org/viewcvs/relax?rev=5320&view=rev
Log:
Partially fixed more code so the consistency tests system test can go further 
before failure.


Modified:
    1.3/specific_fns/consistency_tests.py

Modified: 1.3/specific_fns/consistency_tests.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/consistency_tests.py?rev=5320&r1=5319&r2=5320&view=diff
==============================================================================
--- 1.3/specific_fns/consistency_tests.py (original)
+++ 1.3/specific_fns/consistency_tests.py Fri Apr  4 17:21:16 2008
@@ -438,9 +438,9 @@
         # Alias the current data pipe.
         cdp = relax_data_store[relax_data_store.current_pipe]
 
-        # Test if the run exists.
-        if not self.run in relax_data_store.run_names:
-            raise RelaxNoPipeError, self.run
+        # Test if the current pipe exists.
+        if not relax_data_store.current_pipe:
+            raise RelaxNoPipeError
 
         # Test if the run type is set to 'ct'.
         function_type = relax_data_store.run_types[cdp.run_names.index]




Related Messages


Powered by MHonArc, Updated Fri Apr 04 17:40:12 2008